#!/usr/bin/python

import json

test_csr = """-----BEGIN CERTIFICATE REQUEST-----
MIICsTCCAZkCAQAwbDELMAkGA1UEBhMCQVQxGTAXBgNVBAMMEHRlc3QuZXhhbXBs
ZS5jb20xETAPBgNVBAcMCFNhbHpidXJnMQ0wCwYDVQQKDAR0ZXN0MREwDwYDVQQI
DAhTYWx6YnVyZzENMAsGA1UECwwEdGVzdDCCASIwDQYJKoZIhvcNAQEBBQADggEP
ADCCAQoCggEBAJf++476VCppDLm0gi56XrXZFguhYd98fv3w7FsJezHI3I/kfudX
vEcAAhLA5QqYzCgJbd8qWLtBzewl1hsufhg9bzgST8X7CEShqDB+uZcaaD/amMSG
VHX/UhpzMb9b22N0oXVaNdeh5QER/VZOk/oJrVQLcaXM50Gu38f8VStMJa+Hw+aK
tqunJYyKE1gf1BNy/23mJHf2rLC+Gokei1hfjNerkExi9xXBeSfgCqCUEa45wJ4Z
1DxqaiDCrIWL+iVk2UeOig6bxXsViJGur/6HTABoPmNYAdU+NDaA3t7tluGvM3Y7
0Uk1BqdrK0yT45AN8qqLcJOeVyC02TGIhGkCAwEAAaAAMA0GCSqGSIb3DQEBCwUA
A4IBAQBM+JjmC8cGDm4bt5D7NQMkyXlq7AYrCO6pfQb4CMqHA5tl0yixwN+0JcGW
2viF+8pH5EnMpra9SQGIvbNzV6Vm+EHfoHzQdKDcBD/RJG62cVDxKhRNxEvBwslT
XaIrcP4dliRLZ7J22xaHH0GXb6kFbnIva7mgfVf1+iJcJ/WE/8/sS/HaTLSYdNTY
dvT2iaHmUWOpWzqGvlHe7a2iIxMNtQrtUixAit9heoZurRKYkY3GhX0iojiX0wVH
ntEs3oIIvunPavD1orfDzwYKJg5qJly/oI/ZsAKaf/xQhzg0p7sB5O2A7pk6OV/a
isoMFazQwmz5JpKh8OlsCwUMPwKL
-----END CERTIFICATE REQUEST-----"""

test_key = """-----BEGIN PRIVATE KEY-----
MIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQCX/vuO+lQqaQy5
tIIuel612RYLoWHffH798OxbCXsxyNyP5H7nV7xHAAISwOUKmMwoCW3fKli7Qc3s
JdYbLn4YPW84Ek/F+whEoagwfrmXGmg/2pjEhlR1/1IaczG/W9tjdKF1WjXXoeUB
Ef1WTpP6Ca1UC3GlzOdBrt/H/FUrTCWvh8PmirarpyWMihNYH9QTcv9t5iR39qyw
vhqJHotYX4zXq5BMYvcVwXkn4AqglBGuOcCeGdQ8amogwqyFi/olZNlHjooOm8V7
FYiRrq/+h0wAaD5jWAHVPjQ2gN7e7ZbhrzN2O9FJNQanaytMk+OQDfKqi3CTnlcg
tNkxiIRpAgMBAAECggEASI6zHYTIatps9bWCs5c84Qg5auHmK95tbOH2olq7UX+2
MoZ8Qgly2l3Zn4QvkkhwpOgjZ/X6F6IJICLLu3wNO5sQHa84H6V/Q+v7svK7u7Mi
cuDyLlaFuTJhyjiVVekOqMKDVNb0fvRMsp8Y1Xt7TlASSt2PqftPpd5J+1ise5cI
x5b55icKOSLef7mzyud6txbRsYT5JVA4YTWrfEasOvcJ3ao3nvILOSRY+Q6aNtIL
slVInb7mDsodwCeLpdiSauV+771j9isfdoxdjPoD0H1GW2GoUQo6o2N1smM56YdV
EH3Dc+4CQC5zseAAle9Ws+62TIbqU4gWFVBTQsvvgQKBgQDIZ6s5ZnkZDEOjzPGB
6sSpSunfMkLi2Q3CvqXbrdDFe0IE/4LmkEcZN2yhg0KSjR2xagAGTeDUp471ADNg
b8u7G1+MLIaPrHiGq20jr5b1spP+SICeI6zuT5NpgLQc0ho0FnN/GZDzGLWbYuN1
PWw9PoCSt5fdMJkxhyxJlAeYWQKBgQDCKWpHs+Y+XWKcFYfMFb+bOiqTNQuKhweA
+QZxMqmWnnciUoY3DRB7o+SjbM/IeAsvUmX5CNkGBAcf+XGBT6SJeXzta/kcvya5
4CGY8IfgDFQAXFSfsdryz29C0a3sMZbWFVJv2YBCKFeFQPLSGi+bOoW40iL0nqlS
fuUcwo3KkQKBgAQJUoGNdtLyVEpwTkz3lY5zW9KLCJ3ZEVXi0SRjk9jmaqX/H3vV
XBk97Io0QpsBDKAOKoH1/5lI5rA4mNBQcCIMoxgHrY4nQyYzPbeCSeAZALIWc8C7
pzgFkkqFtRr/gFecPCdLNIgw7zd5/mrWGeAB6kUKPZzO5ccBmfrBaIXBAoGAapJY
56pzAmA3s/yNYRO+6/DtVYeUIiEjmUMWqiNoumeYdJpfWPAuz+6RnLIpCpv5Z6wO
lLaqiIbFcmN0TcntQhgQ3jCZt5GkK/o99rhvnCaoJNqJCG6TAxugskhs8mv1ouRp
L0NvBuElyNpxbak54DYrF9sfnK1JuyIzl6miMkECgYEAsfiDP6FeTv5bvF0YRBLY
6U2XSkyXM8ULj2SAfawMC5Z0q9/j2JlcCwQffSlnZOSHlh7hYadL0wh5nklyoLdR
QmEjbPvVM6LvyZtaUiibPjysES5Cc6Fhr5JCBsPaFFJ1v0FZR3+qLHZAju85mCxh
qHWLrKKXm4CsX16jXPYLh0o=
-----END PRIVATE KEY-----"""

wildcard_csr = """-----BEGIN CERTIFICATE REQUEST-----
MIICsjCCAZoCAQAwbTELMAkGA1UEBhMCQVQxFjAUBgNVBAMMDSouZXhhbXBsZS5j
b20xETAPBgNVBAcMCFNhbHpidXJnMQ0wCwYDVQQKDAR0ZXN0MREwDwYDVQQIDAhT
YWx6YnVyZzERMA8GA1UECwwId2lsZGNhcmQwggEiMA0GCSqGSIb3DQEBAQUAA4IB
DwAwggEKAoIBAQDM4PnosUgvhLGjC6EAhUCuAoQCXsO4C0ac3p9ktemlrBmrAFU2
o2lwOyhncO14PUbqy4Uj+Kw2Fz0M7xvPN5TwtjD9A0lQMZCwoc9RmHF+BipCHZmG
Crv1D/5hRjS9dM59l1N/7k/3B9SyO/y6vj7NVhbj37rSNTfKuQBZsCnwYfCKgEvo
7IGtlKgkRzIGHhdHnbIWlAvfoKx0J2icd5VV2g8RjOmKliJmfolwSzYSwbz0mrZU
JTM2rH/yIcJ98TU+XF3X5AmOMafL0wELi3/7J0a8uLRanDomHSzXxpS5iipunN3e
C2InK03+sVYNpQw7/Z5LswrHzY6QPZiRv5dfAgMBAAGgADANBgkqhkiG9w0BAQsF
AAOCAQEAG/C57AZLnTALDAUdDnQTTQgziZ9lTyfIWiZbJphc1Dow+R7Yya9wuFKd
tWK7hbGkYA2U35R1nH3Evni1NaZlXB4qYtZ3ur62SRnWvRmraW9O+p8korv8jXpf
V8FPOHjvdO1vXxRLRQA3RcqbMeJLz9ittIDtPIPcGv/CAGQj5spTEAzIiWahB97k
pRgbg9OzbbwRD6tPNWt6GYSpI96G4FInXiLZtj8VLJJb3H1k2ni8wqW10BQIwUOo
V4PAgcQ2VDryUYPlOWQZ/+u4iUeoutuNVES1eB/UOVgZKcV5I2EZh8kvbcUP4Ox5
tLZBnrJZXPuGqjv9jDWTi1WevCFIlA==
-----END CERTIFICATE REQUEST-----"""

wildcard_key = """-----BEGIN PRIVATE KEY-----
MIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQDM4PnosUgvhLGj
C6EAhUCuAoQCXsO4C0ac3p9ktemlrBmrAFU2o2lwOyhncO14PUbqy4Uj+Kw2Fz0M
7xvPN5TwtjD9A0lQMZCwoc9RmHF+BipCHZmGCrv1D/5hRjS9dM59l1N/7k/3B9Sy
O/y6vj7NVhbj37rSNTfKuQBZsCnwYfCKgEvo7IGtlKgkRzIGHhdHnbIWlAvfoKx0
J2icd5VV2g8RjOmKliJmfolwSzYSwbz0mrZUJTM2rH/yIcJ98TU+XF3X5AmOMafL
0wELi3/7J0a8uLRanDomHSzXxpS5iipunN3eC2InK03+sVYNpQw7/Z5LswrHzY6Q
PZiRv5dfAgMBAAECggEAGsW7YoDoIe2BGQFIBL1k+lgxz+16Pe6bR5x/z7VF1vRq
VkIw4HbyLExOt1W2cmPvhHcb6ttwBZF71NjaFXX57IqiVC29wtD3S12Zrdvx2LoN
g55ClZWJgjiY0TVPZwKAiUDhFHKb2HgZf0D/gZeitUpuq1BtJVL2+3K5bP7sPBEU
dwo+Rj8STJD/a20oyg7VR+kyKspyZqqkozQ22+eiscq1Pa7skEhRNx1UuHovB4F8
m7OkAtm6HzrUTcxTAE8ivRxgSlcg5ACTGkwDZyA5fDVHxYgiuRZgjcowsa78Cy//
PuJcE1qRm7vmQ1ghMpX3k07XoW5n9OMYIiTxyP7j4QKBgQDlfUQCw2n1ovbiVSJw
j1DCt7Sl8KOXCO/C1bVHy5BM/7BRo2d88kAeAQJtvde5LhzhVgNqCL9m1tVntDzz
qaNPZUP3VauwuSekb1ZF2q3knkf/Z4SpvJ0AlBlCTSCOfBRUQkBn54baQjBlBTRW
T8xu5seL4YnY0Q3mSreIkCvnPQKBgQDki+Yn5C8ws1nbcE6ZT9Vcfcf74xTFKBZU
OG1IoR7OF9MzMf9VbBGUBG/qvSApgIxXsqvfaTz+7IvHg1hok+leIN0r1ojXPnTQ
77RmcPdqchKxyTByXh0RgmOeI9PjQrhdUjeLbzRj1b/m9ufg7kwODK3pwKs/BKWu
F+9n86/CywKBgQDMCDoeZtTfIltz0RNElfbMl/3Rhwg68SQRymVZBqAuBSoi+y+4
Q71Dr8wT+7Q/HMNqiEmSzWI2sYycnf+O92SN40+xKAb0oTmglahThOAUIbGLXuLw
8hN4fzOR4favF5wPabPPbWZUyII0XpMwpdPxSddiA0zGat97vzQ8A0o1VQKBgEg/
BTGFC3ncqEIa/W2vc+X6CPbSMOWmJ3DWKY21CRTjKStc2bc6I1BkGrDcukcEUNkE
LRrBnLuFMSaPmantX+8WenP6LGXGY40MyT085qlqiAhVbhApOg0n56+86aVEmR0+
+ToFnE0W68PqNyC+k6I5Vdy3wCp6oJkpDdARk3UDAoGBAN/ubj1ySlGKgHKtUTzD
hvje23KmXGXilDBRjqjMIOhANQNMPYLUmzxAWCjWxKJBVWfR87DClKjbU/d8pYn5
sWGrKeoci2WQFIhzdD6Z672vTC6hXZbjWJXqRuPpdjyWHbx1zFPOkV9t24GsVhjl
Rk50TgxqBf/CRDYXI4dZDHhz
-----END PRIVATE KEY-----"""


dehydrated_domains = {
    '*.example.com': {
        'base_filename': '_wildcard_.example.com',
        'dh_param_size': 4096,
        'challengetype': 'dns-01',
        'subject_alternative_names': [],
        'csr': wildcard_csr,
        'dehydrated_hook': 'dns-01.sh',
        'dehydrated_environment': {},
    },
    'test.example.com': {
        'base_filename': 'test.example.com',
        'dh_param_size': 4096,
        'challengetype': 'dns-01',
        'subject_alternative_names': [],
        'csr': test_csr,
        'dehydrated_hook': 'dns-01.sh',
        'dehydrated_environment': {'PATH': '/tmp'},
    }
}

print("dehydrated_domains: " + json.dumps(dehydrated_domains))
